.. _installing_galaxy_collections:

Installing collections from Galaxy
==================================

.. include:: ../../shared_snippets/installing_collections.txt


Installing an older version of a collection
-------------------------------------------

.. include:: ../../shared_snippets/installing_older_collection.txt

Install multiple collections with a requirements file
-----------------------------------------------------

.. include:: ../../shared_snippets/installing_multiple_collections.txt

Galaxy server configuration list
--------------------------------

.. include:: ../../shared_snippets/galaxy_server_list.txt
